@@ -804,7 +804,10 @@ class Sf:
         profile_metadata = profile_metadata[['id', 'fullName']].copy()
         profile_metadata
         user_profile_id = transform_sf_result_set_rec(self.sf.query_all(f"Select Id, ProfileId FROM User WHERE Username = '{username}'")['records'])
-        user_profile = profile_metadata[profile_metadata['id'] == user_profile_id['User.ProfileId'].values[0]]['fullName'].values[0]
+        if len(profile_metadata[profile_metadata['id'] == user_profile_id['User.ProfileId'].values[0]]['fullName']) == 0:
+            raise Exception("User does not have a retrievable / valid profile")
+        else:
+            user_profile = profile_metadata[profile_metadata['id'] == user_profile_id['User.ProfileId'].values[0]]['fullName'].values[0]
 
         async_profile_read = async_wrap(self.metadata_read)
         
